#
# spec file for package perl-UNIVERSAL-require
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name UNIVERSAL-require
Name:           perl-UNIVERSAL-require
Version:        0.19
Release:        1.17
Summary:        Require() modules from a variable [deprecated]
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NE/NEILB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Before using this module, you should look at the alternatives, some of
which are listed in SEE ALSO below.

This module provides a safe mechanism for loading a module at runtime, when
you have the name of the module in a variable.

If you've ever had to do this...

    eval "require $module";

to get around the bareword caveats on require(), this module is for you. It
creates a universal require() class method that will work with every Perl
module and its secure. So instead of doing some arcane eval() work, you can
do this:

    $module->require;

It doesn't save you much typing, but it'll make a lot more sense to someone
who's not a ninth level Perl acolyte.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Sun Mar 28 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.19
  see /usr/share/doc/packages/perl-UNIVERSAL-require/Changes
  0.19 2021-03-27 NEILB
  - Noted that the module is now deprecated
  - Added a list of alternatives to SEE ALSO
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-UNIVERSAL-require/Changes
  0.18 2015-02-24
  - Skip the taint test if Perl was compiled without taint support.
    RAZ++
  - Changed use of "use vars" to "our"
  - Added strict and warnings to PREREQ_PM
  0.17 2014-04-19
  - Check for valid module names. RT#94866 from TOBYINK.
  - Changed used of die() to croak() RT#23113
  - Fixed typo in pod (fschlich++)
* Mon Feb 24 2014 coolo@suse.com
- updated to 0.16
  - All seems fine with previous dev release
  - Added README
  - Specified min version of perl 5.6.0
  - Now "use warnings"
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.15
  - Hadn't specific meta-spec version 2, so github repo wasn't turning
    up in the metadata.
  - Changed the repository meta_merge to the new format
  - Tweaked format (mainly release dates) to conform to CPAN::Changes::Spec
  - first test release by NEILB after getting comaint
  - no changes other than specifying github repository
* Fri Feb 10 2012 coolo@suse.com
- update to 0.13
  Bug Fixes
  * $module->require now always resets $@ which removes a trap of using $@
    to indicate an error, rather than checking $module->require directly.
    [rt.cpan.org 44444]
  Test Fixes
  * bleadperl introduced a new warning deprecating "use UNIVERSAL"
    (thank goodness) which interfered with t/require.t
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug 20 2007 mrueckert@suse.de
- initial package
